==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/PoleLiczbaI.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.generic.GenericDPSObject;

public abstract class PoleLiczbaI extends GenericDPSObject {
    /**
     * POLE_LICZBA_I.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * POLE_LICZBA_I.WARTOSC
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer wartosc;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return POLE_LICZBA_I.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * POLE_LICZBA_I.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return POLE_LICZBA_I.WARTOSC
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getWartosc() {
        return wartosc;
    }

    /**
     * POLE_LICZBA_I.WARTOSC
     *
     * @param wartosc
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setWartosc(Integer wartosc) {
        this.wartosc = wartosc;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        PoleLiczbaI other = (PoleLiczbaI) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getWartosc() == null ? other.getWartosc() == null : this.getWartosc().equals(other.getWartosc()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getWartosc() == null) ? 0 : getWartosc().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", wartosc=").append(wartosc);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/PoleLiczbaI.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class PoleLiczbaI extends GenericDPSObject {
    /**
     * POLE_LICZBA_I.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * POLE_LICZBA_I.WARTOSC
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer wartosc;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return POLE_LICZBA_I.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * POLE_LICZBA_I.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return POLE_LICZBA_I.WARTOSC
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getWartosc() {
        return wartosc;
    }

    /**
     * POLE_LICZBA_I.WARTOSC
     *
     * @param wartosc
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setWartosc(Integer wartosc) {
        this.wartosc = wartosc;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        PoleLiczbaI other = (PoleLiczbaI) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getWartosc() == null ? other.getWartosc() == null : this.getWartosc().equals(other.getWartosc()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getWartosc() == null) ? 0 : getWartosc().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", wartosc=").append(wartosc);
        sb.append("]");
        return sb.toString();
    }
}
